
# DO NOT EDIT THIS FILE -- AUTOGENERATED BY PANTS
# Target: src/ai/backend/accelerator/cuda_open:dist

from setuptools import setup

setup(**{
    'author': 'Lablup Inc. and contributors',
    'classifiers': [
        'Intended Audience :: Developers',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Environment :: No Input/Output (Daemon)',
        'Topic :: Scientific/Engineering',
        'Topic :: Software Development',
        'Development Status :: 5 - Production/Stable',
        'Programming Language :: Python :: 3.13',
        'License :: OSI Approved :: GNU Lesser General Public License v3 or later (LGPLv3+)',
    ],
    'description': 'Backend.AI Accelerator Plugin for CUDA',
    'entry_points': {
        'backendai_accelerator_v21': [
            'cuda = ai.backend.accelerator.cuda_open.plugin:CUDAPlugin',
        ],
    },
    'install_requires': (
        'aiodocker==0.24.0',
        'aiotools~=2.2.3',
        """backend.ai-agent==26.2.4
""",
        """backend.ai-cli==26.2.4
""",
        """backend.ai-common==26.2.4
""",
        """backend.ai-kernel-binary==26.2.4
""",
        """backend.ai-kernel-helper==26.2.4
""",
        """backend.ai-logging==26.2.4
""",
        """backend.ai-plugin==26.2.4
""",
    ),
    'license': 'LGPLv3',
    'long_description': """Backend.AI Accelerator Plugin for CUDA
======================================

Just install this along with Backend.AI agents, using the same virtual environment.
This will allow the agents to detect CUDA devices on their hosts and make them
available to Backend.AI kernel sessions.

```console
$ pip install backend.ai-accelerator-cuda-open
```

This open-source edition of CUDA plugins support allocation of one or more CUDA
devices to a container, slot-by-slot.
""",
    'long_description_content_type': 'text/markdown',
    'name': 'backend.ai-accelerator-cuda-open',
    'namespace_packages': (
    ),
    'package_data': {
        'ai.backend.accelerator.cuda_open': (
            'VERSION',
            'py.typed',
        ),
    },
    'packages': (
        'ai.backend.accelerator.cuda_open',
    ),
    'project_urls': {
        'Documentation': 'https://docs.backend.ai/',
        'Source': 'https://github.com/lablup/backend.ai',
    },
    'python_requires': '>=3.13,<3.14',
    'url': 'https://github.com/lablup/backend.ai',
    'version': """26.2.4
""",
    'zip_safe': False,
})
